sqltriples.Query.IntersectionOfPredicates

Package sqltriples :: Module Query :: Class IntersectionOfPredicates |
[show private | hide private]
[frames | no frames]

## Class IntersectionOfPredicates

          CombinedResults --+
                            |
      CombinedTopLevelResults --+
                                |
                     Intersection --+
                                    |
    AbstractQuery --+               |
                    |               |
                Query --+           |
                        |           |
                  Results --+       |
                            |       |
                SingleResults --+   |
                                |   |
                       Predicates --+
                                    |
                                   IntersectionOfPredicates

Method Summary
| `__init__(self, store, queries)`
Inherited from CombinedTopLevelResults
| ``get_query`(self, index)`
| ``get_subquery`(self, parent_columns, parent_index, index, match_first, match_parent, match_child)`
Inherited from Query
| ``__getitem__`(self, i)`
| ``__len__`(self)`
| ``__repr__`(self)`

Class Variable Summary
Inherited from Intersection
`int` | `in_parentheses` = 0
`str` | `operator` = `'intersect'`
Inherited from Predicates
`list` | `exposed_columns` = `[('predicate', None)]`
Inherited from AbstractQuery
`list` | `table_columns` = `[('subject', 'subject_type', 0), ('predi...`

Generated by Epydoc 2.1 on Sat Sep 30 00:54:37 2006 | http://epydoc.sf.net